==> tfp_nightly-0.13.0.dev20210330-py2.py3-none-any.whl: tensorflow_probability/python/experimental/distributions/__init__.py <==
# Copyright 2020 The TensorFlow Probability Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""TensorFlow Probability experimental distributions package."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from tensorflow_probability.python.distributions.log_prob_ratio import log_prob_ratio
from tensorflow_probability.python.experimental.distributions.increment_log_prob import IncrementLogProb
from tensorflow_probability.python.experimental.distributions.joint_density_coroutine import JointDensityCoroutine
from tensorflow_probability.python.experimental.distributions.joint_distribution_pinned import JointDistributionPinned
from tensorflow_probability.python.experimental.distributions.mvn_precision_factor_linop import MultivariateNormalPrecisionFactorLinearOperator


__all__ = [
    'log_prob_ratio',
    'IncrementLogProb',
    'JointDensityCoroutine',
    'JointDistributionPinned',
    'MultivariateNormalPrecisionFactorLinearOperator',
]

==> tfp_nightly-0.14.0.dev20210829-py2.py3-none-any.whl: tensorflow_probability/python/experimental/distributions/__init__.py <==
# Copyright 2020 The TensorFlow Probability Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""TensorFlow Probability experimental distributions package."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from tensorflow_probability.python.distributions.log_prob_ratio import log_prob_ratio
from tensorflow_probability.python.experimental.distributions import marginal_fns
from tensorflow_probability.python.experimental.distributions.increment_log_prob import IncrementLogProb
from tensorflow_probability.python.experimental.distributions.joint_distribution_pinned import JointDistributionPinned
from tensorflow_probability.python.experimental.distributions.mvn_precision_factor_linop import MultivariateNormalPrecisionFactorLinearOperator


__all__ = [
    'log_prob_ratio',
    'IncrementLogProb',
    'JointDistributionPinned',
    'marginal_fns',
    'MultivariateNormalPrecisionFactorLinearOperator',
]
